@@ -221,8 +221,6 @@ DATA blocks, and it defaults to being configured for POD blocks.
 
   @@ end
 
-=cut
-
 =head2 DATA syntax (nested)
 
   __DATA__
@@ -241,8 +239,6 @@ DATA blocks, and it defaults to being configured for POD blocks.
 
   @@ end
 
-=cut
-
 =head2 POD syntax
 
   # pod syntax
@@ -273,8 +269,6 @@ DATA blocks, and it defaults to being configured for POD blocks.
 
   =cut
 
-=cut
-
 =head2 POD syntax (nested)
 
   # pod syntax (nested)
@@ -296,8 +290,6 @@ DATA blocks, and it defaults to being configured for POD blocks.
 
 =cut
 
-=cut
-
 =head1 INHERITS
 
 This package inherits behaviors from:
@@ -546,18 +538,4 @@ I<Since C<0.01>>
 
 =back
 
-=cut
-
-=head1 AUTHORS
-
-Cpanery, C<cpanery@cpan.org>
-
-=cut
-
-=head1 LICENSE
-
-Copyright (C) 2021, Cpanery
-
-Read the L<"license"|https://github.com/cpanery/venus/blob/master/LICENSE> file.
-
 =cut
\ No newline at end of file
