@@ -727,18 +727,4 @@ B<example 1>
 
   # 1
 
-=back
-
-=head1 AUTHORS
-
-Cpanery, C<cpanery@cpan.org>
-
-=cut
-
-=head1 LICENSE
-
-Copyright (C) 2021, Cpanery
-
-Read the L<"license"|https://github.com/cpanery/venus/blob/master/LICENSE> file.
-
-=cut
\ No newline at end of file
+=back
\ No newline at end of file
