@@ -89,18 +89,4 @@ This package integrates behaviors from:
 
 L<Venus::Role::Proxyable>
 
-=cut
-
-=head1 AUTHORS
-
-Cpanery, C<cpanery@cpan.org>
-
-=cut
-
-=head1 LICENSE
-
-Copyright (C) 2021, Cpanery
-
-Read the L<"license"|https://github.com/cpanery/venus/blob/master/LICENSE> file.
-
 =cut
\ No newline at end of file
