@@ -23,6 +23,12 @@ sub print_pretty {
   return $self->printer($self->dump_pretty(@args));
 }
 
+sub print_string {
+  my ($self, $method, @args) = @_;
+
+  return $self->printer($method ? scalar($self->$method(@args)) : $self);
+}
+
 sub printer {
   my ($self, @args) = @_;
 
@@ -41,6 +47,12 @@ sub say_pretty {
   return $self->printer($self->dump_pretty(@args), "\n");
 }
 
+sub say_string {
+  my ($self, $method, @args) = @_;
+
+  return $self->printer(($method ? scalar($self->$method(@args)) : $self), "\n");
+}
+
 1;
 
 
@@ -194,6 +206,34 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 print_string
+
+  print_string(Str | CodeRef $method, Any @args) (Any)
+
+The print_string method prints a string representation of the underlying data
+without using a dump. This method supports dispatching, i.e. providing a
+method name and arguments whose return value will be acted on by this method.
+
+I<Since C<0.09>>
+
+=over 4
+
+=item print_string example 1
+
+  package main;
+
+  my $example = Example->new(test => 123);
+
+  my $print_string = $example->print_string;
+
+  # 'Example'
+
+  # 1
+
+=back
+
+=cut
+
 =head2 say
 
   say(Any @data) (Any)
@@ -285,16 +325,31 @@ I<Since C<0.01>>
 
 =cut
 
-=head1 AUTHORS
+=head2 say_string
 
-Cpanery, C<cpanery@cpan.org>
+  say_string(Str | CodeRef $method, Any @args) (Any)
 
-=cut
+The say_string method prints a string representation of the underlying data
+without using a dump, with a trailing newline. This method supports
+dispatching, i.e. providing a method name and arguments whose return value will
+be acted on by this method.
 
-=head1 LICENSE
+I<Since C<0.09>>
 
-Copyright (C) 2021, Cpanery
+=over 4
 
-Read the L<"license"|https://github.com/cpanery/venus/blob/master/LICENSE> file.
+=item say_string example 1
+
+  package main;
+
+  my $example = Example->new(test => 123);
+
+  my $say_string = $example->say_string;
+
+  # "Example\n"
+
+  # 1
+
+=back
 
 =cut
\ No newline at end of file
